@@ -8,13 +8,13 @@ import org.gcube.portlets.user.td.columnwidget.client.dimension.ConnectCodelistD
 import org.gcube.portlets.user.td.columnwidget.client.dimension.ConnectCodelistListener;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionDialog;
 import org.gcube.portlets.user.td.columnwidget.client.dimension.DimensionRowSelectionListener;
+import org.gcube.portlets.user.td.columnwidget.client.properties.ColumnDataPropertiesCombo;
 import org.gcube.portlets.user.td.columnwidget.client.properties.ShowOccurrencesTypeProperties;
 import org.gcube.portlets.user.td.columnwidget.client.resources.ResourceBundle;
 import org.gcube.portlets.user.td.columnwidget.client.store.ShowOccurrencesTypeElement;
 import org.gcube.portlets.user.td.columnwidget.client.store.ShowOccurrencesTypeStore;
 import org.gcube.portlets.user.td.columnwidget.client.utils.UtilsGXT3;
 import org.gcube.portlets.user.td.gwtservice.client.rpc.TDGWTServiceAsync;
-import org.gcube.portlets.user.td.gwtservice.shared.Constants;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsFinalException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTIsLockedException;
 import org.gcube.portlets.user.td.gwtservice.shared.exception.TDGWTSessionExpiredException;
@@ -33,6 +33,7 @@ import org.gcube.portlets.user.td.widgetcommonevent.client.event.SessionExpiredE
 import org.gcube.portlets.user.td.widgetcommonevent.client.type.SessionExpiredType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.CellData;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.RequestProperties;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.RequestPropertiesParameterType;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
 
 import com.allen_sauer.gwt.log.client.Log;
@@ -41,18 +42,22 @@ import com.google.gwt.cell.client.Cell.Context;
 import com.google.gwt.core.client.GWT;
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.core.client.Scheduler.ScheduledCommand;
+import com.google.gwt.dom.client.Element;
+import com.google.gwt.dom.client.NodeList;
 import com.google.gwt.dom.client.Style.Unit;
 import com.google.gwt.event.logical.shared.SelectionEvent;
 import com.google.gwt.event.logical.shared.SelectionHandler;
 import com.google.gwt.safecss.shared.SafeStylesBuilder;
 import com.google.gwt.safehtml.shared.SafeHtmlBuilder;
 import com.google.gwt.user.client.rpc.AsyncCallback;
+import com.google.gwt.user.client.ui.FlexTable;
 import com.google.gwt.user.client.ui.HTML;
 import com.google.web.bindery.event.shared.EventBus;
 import com.sencha.gxt.cell.core.client.ButtonCell.IconAlign;
 import com.sencha.gxt.cell.core.client.form.ComboBoxCell.TriggerAction;
 import com.sencha.gxt.core.client.IdentityValueProvider;
 import com.sencha.gxt.core.client.Style.SelectionMode;
+import com.sencha.gxt.core.client.dom.XElement;
 import com.sencha.gxt.core.client.resources.ThemeStyles;
 import com.sencha.gxt.core.client.util.Format;
 import com.sencha.gxt.core.client.util.Margins;
@@ -72,11 +77,14 @@ import com.sencha.gxt.widget.core.client.container.BoxLayoutContainer.BoxLayoutD
 import com.sencha.gxt.widget.core.client.container.BoxLayoutContainer.BoxLayoutPack;
 import com.sencha.gxt.widget.core.client.container.HBoxLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.HBoxLayoutContainer.HBoxLayoutAlign;
+import com.sencha.gxt.widget.core.client.container.HorizontalLayoutContainer;
+import com.sencha.gxt.widget.core.client.container.HorizontalLayoutContainer.HorizontalLayoutData;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer;
 import com.sencha.gxt.widget.core.client.container.VerticalLayoutContainer.VerticalLayoutData;
 import com.sencha.gxt.widget.core.client.event.SelectEvent;
 import com.sencha.gxt.widget.core.client.event.SelectEvent.SelectHandler;
 import com.sencha.gxt.widget.core.client.form.ComboBox;
+import com.sencha.gxt.widget.core.client.form.FieldLabel;
 import com.sencha.gxt.widget.core.client.form.TextField;
 import com.sencha.gxt.widget.core.client.grid.CheckBoxSelectionModel;
 import com.sencha.gxt.widget.core.client.grid.ColumnConfig;
@@ -84,7 +92,6 @@ import com.sencha.gxt.widget.core.client.grid.ColumnModel;
 import com.sencha.gxt.widget.core.client.grid.Grid;
 import com.sencha.gxt.widget.core.client.grid.RowNumberer;
 import com.sencha.gxt.widget.core.client.info.Info;
-import com.sencha.gxt.widget.core.client.toolbar.LabelToolItem;
 import com.sencha.gxt.widget.core.client.toolbar.ToolBar;
 
 /**
@@ -96,31 +103,35 @@ import com.sencha.gxt.widget.core.client.toolbar.ToolBar;
 public class ReplaceBatchPanel extends FramedPanel implements
 		SingleValueReplaceListener, DimensionRowSelectionListener,
 		ConnectCodelistListener {
-	protected String WIDTH = "560px";
-	protected String HEIGHT = "520px";
-	protected EventBus eventBus;
-	protected TextField label = null;
-	protected TRId trId;
-	protected String columnName;
+	private static final String DON_T_REPLACE = "Don't replace";
+	private static final String WIDTH = "560px";
+	private static final String HEIGHT = "550px";
+	private static final String GRID_HEIGHT = "344px";
+	private static final String TOOLBAR_HEAD_HEIGHT = "102px";
+	private static final String CONNECTION_FIELD_WIDTH = "470px";
+	private static final int SHOW_OCCURENCE_TYPE_WIDTH = 100;
+	private static final String COMBOCOLS_WIDTH = "510px";
 
-	protected RefColumn refColumn;
-	protected String columnId;
-	protected ConditionCode conditionCode; // For Curation
-	protected String validationColumnColumnId; // For Curation
-	protected RequestProperties requestProperties;
-	protected boolean curation;
-	protected ColumnData column;
-	protected boolean hasValidationColumns;
-	protected ShowOccurrencesType showOccurencesType;
-	protected ColumnData connection;
+	private EventBus eventBus;
+	private TRId trId;
+	private ArrayList<ColumnData> columns;
 
-	protected ReplaceBatchDialog parent;
+	private RefColumn refColumn;
+	private String columnLocalId;
+	private ConditionCode conditionCode; // For Curation
+	private String validationColumnColumnId; // For Curation
+
+	private boolean curation;
+	private ColumnData column;
+	private boolean hasValidationColumns;
+	private ShowOccurrencesType showOccurencesType;
+	private ColumnData connection;
+
+	private ReplaceBatchDialog parent;
 
 	private ReplaceEntry currentReplaceEntry;
 	private int currentRowIndex;
 
-	protected static final String DON_T_REPLACE = "Don't replace";
-
 	private TextButton btnSave;
 	private TextButton btnClose;
 
@@ -133,32 +144,33 @@ public class ReplaceBatchPanel extends FramedPanel implements
 	private TextButton btnDisconnect;
 	private TextField connectionField;
 
-	protected ListLoader<ListLoadConfig, ListLoadResult<ReplaceEntry>> loader;
-	protected Grid<ReplaceEntry> grid;
-	protected ListStore<ReplaceEntry> store;
-	protected HTML info;
+	private ListLoader<ListLoadConfig, ListLoadResult<ReplaceEntry>> loader;
+	private Grid<ReplaceEntry> grid;
+	private ListStore<ReplaceEntry> store;
+	private HTML info;
 
 	private boolean simpleReplace;
 
+	private ComboBox<ColumnData> comboCols;
+
 	public ReplaceBatchPanel(ReplaceBatchDialog parent, TRId trId,
 			RequestProperties requestProperties, EventBus eventBus) {
 		this.curation = true;
 		this.parent = parent;
 		this.trId = trId;
-		this.requestProperties = requestProperties;
 		this.eventBus = eventBus;
 
 		InvocationS invocationS = (InvocationS) requestProperties.getMap().get(
-				Constants.REQUEST_PROPERTIES_INVOCATIONS);
-
-		columnId = invocationS.getColumnId();
+				RequestPropertiesParameterType.InvocationS);
 
+		columnLocalId = invocationS.getColumnId();
+		
 		refColumn = invocationS.getRefColumn();
 
 		conditionCode = (ConditionCode) requestProperties.getMap().get(
-				Constants.REQUEST_PROPERTIES_CONDITIONCODE);
+				RequestPropertiesParameterType.ConditionCode);
 		validationColumnColumnId = (String) requestProperties.getMap().get(
-				Constants.REQUEST_PROPERTIES_VALIDATIONCOLUMNCOLUMNID);
+				RequestPropertiesParameterType.ValidationColumnColumnId);
 
 		connection = null;
 		hasValidationColumns = false;
@@ -170,11 +182,11 @@ public class ReplaceBatchPanel extends FramedPanel implements
 	}
 
 	public ReplaceBatchPanel(ReplaceBatchDialog parent, TRId trId,
-			String columnName, EventBus eventBus) {
+			String columnLocalId, EventBus eventBus) {
 		this.curation = false;
 		this.parent = parent;
 		this.trId = trId;
-		this.columnName = columnName;
+		this.columnLocalId = columnLocalId;
 		this.eventBus = eventBus;
 		this.conditionCode = null;
 		this.validationColumnColumnId = null;
@@ -182,9 +194,9 @@ public class ReplaceBatchPanel extends FramedPanel implements
 		connection = null;
 		hasValidationColumns = false;
 		Log.debug("Create BatchReplacePanel(): [" + trId.toString()
-				+ " , columnName:" + columnName + "]");
+				+ " , columnLocalId:" + columnLocalId + "]");
 		init();
-		retrieveColumn();
+		retrieveColumnsWithOnlyViewColumnInRel();
 
 	}
 
@@ -198,8 +210,33 @@ public class ReplaceBatchPanel extends FramedPanel implements
 	protected void create() {
 		showOccurencesType = ShowOccurrencesType.ONLYERRORS;
 
-		toolBarHead = new ToolBar();
-		toolBarHead.add(new LabelToolItem("Show: "));
+		FlexTable flexTable = new FlexTable();
+		flexTable.setCellSpacing(1);
+
+		// Combo Column
+		ColumnDataPropertiesCombo propsCols = GWT
+				.create(ColumnDataPropertiesCombo.class);
+		Log.debug("Props: " + propsCols);
+		final ListStore<ColumnData> storeCols = new ListStore<ColumnData>(
+				propsCols.id());
+		Log.debug("Store Col: " + storeCols);
+		storeCols.addAll(columns);
+
+		Log.debug("StoreCol created");
+		comboCols = new ComboBox<ColumnData>(storeCols, propsCols.label());
+
+		Log.debug("Combo Threshold created");
+
+		comboCols.addSelectionHandler(comboColsSelection());
+
+		comboCols.setEmptyText("Select a column...");
+		comboCols.setEditable(false);
+		comboCols.setTriggerAction(TriggerAction.ALL);
+		comboCols.setWidth(COMBOCOLS_WIDTH);
+
+		FieldLabel columnField = new FieldLabel(comboCols, "Column");
+
+		flexTable.setWidget(0, 0, columnField);
 
 		// Create Combo Show
 		ShowOccurrencesTypeProperties propsShowOccurrencesType = GWT
@@ -214,21 +251,26 @@ public class ReplaceBatchPanel extends FramedPanel implements
 		addHandlersForShowOccurrencesType(propsShowOccurrencesType.label());
 
 		comboShowOccurrencesType.setEmptyText("Select a show type...");
-		comboShowOccurrencesType.setWidth(100);
+		comboShowOccurrencesType.setWidth(SHOW_OCCURENCE_TYPE_WIDTH);
 		comboShowOccurrencesType.setTypeAhead(true);
 		comboShowOccurrencesType.setEditable(false);
 		comboShowOccurrencesType.setTriggerAction(TriggerAction.ALL);
+
 		comboShowOccurrencesType
 				.setValue(ShowOccurrencesTypeStore.onlyErrorsElement);
 
-		toolBarHead.add(comboShowOccurrencesType);
+		FieldLabel comboShowOccurrencesTypeField = new FieldLabel(
+				comboShowOccurrencesType, "Show");
+		flexTable.setWidget(1, 0, comboShowOccurrencesTypeField);
+
+		HorizontalLayoutContainer connectionLayout = new HorizontalLayoutContainer();
+		if (column == null || !column.isViewColumn()) {
 
-		if (!column.isViewColumn()) {
 			// Connect Codelist
 			btnConnect = new TextButton();
 			btnConnect.setIcon(ResourceBundle.INSTANCE.codelistLink24());
 			btnConnect.setIconAlign(IconAlign.TOP);
-			btnConnect.setTitle("Connect");
+			btnConnect.setToolTip("Connect");
 			btnConnect.addSelectHandler(new SelectHandler() {
 
 				public void onSelect(SelectEvent event) {
@@ -240,14 +282,15 @@ public class ReplaceBatchPanel extends FramedPanel implements
 
 			});
 
-			toolBarHead.add(btnConnect);
+			connectionLayout.add(btnConnect, new HorizontalLayoutData(-1, 1,
+					new Margins(1)));
 
 			// Disconnect Codelist
 			btnDisconnect = new TextButton();
 			btnDisconnect
 					.setIcon(ResourceBundle.INSTANCE.codelistLinkBreak24());
 			btnDisconnect.setIconAlign(IconAlign.TOP);
-			btnDisconnect.setTitle("Disconnect");
+			btnDisconnect.setToolTip("Disconnect");
 			btnDisconnect.addSelectHandler(new SelectHandler() {
 
 				public void onSelect(SelectEvent event) {
@@ -258,16 +301,33 @@ public class ReplaceBatchPanel extends FramedPanel implements
 				}
 
 			});
-			toolBarHead.add(btnDisconnect);
+			connectionLayout.add(btnDisconnect, new HorizontalLayoutData(-1, 1,
+					new Margins(1)));
 
 			connectionField = new TextField();
-			toolBarHead.add(connectionField);
+			connectionField.setWidth(CONNECTION_FIELD_WIDTH);
+			connectionLayout.add(connectionField, new HorizontalLayoutData(-1,
+					1, new Margins(1)));
 
 		} else {
 			connectionField = new TextField();
-			toolBarHead.add(connectionField);
+			connectionField.setWidth(CONNECTION_FIELD_WIDTH);
+
+			connectionLayout.add(connectionField, new HorizontalLayoutData(-1,
+					1, new Margins(1)));
+
 		}
 
+		FieldLabel conField = new FieldLabel(connectionLayout, "Connection");
+		flexTable.setWidget(2, 0, conField);
+
+		cleanCells(flexTable.getElement());
+
+		toolBarHead = new ToolBar();
+		toolBarHead.setHeight(TOOLBAR_HEAD_HEIGHT);
+		// toolBarHead.setHeight("");
+		toolBarHead.add(flexTable, new BoxLayoutData(new Margins(0)));
+
 		// Create Grid
 		IdentityValueProvider<ReplaceEntry> identity = new IdentityValueProvider<ReplaceEntry>();
 		CheckBoxSelectionModel<ReplaceEntry> sm = new CheckBoxSelectionModel<ReplaceEntry>(
@@ -275,10 +335,10 @@ public class ReplaceBatchPanel extends FramedPanel implements
 
 		RowNumberer<ReplaceEntry> number = new RowNumberer<ReplaceEntry>(
 				identity);
-		// number.setFixed(false);
-		// number.setResizable(false);
 		number.setWidth(50);
-		number.setColumnClassSuffix("");
+
+		number.setCellClassName("");
+		number.setCellPadding(true);
 		number.setHeader("N.");
 		SafeStylesBuilder styleBuilder = new SafeStylesBuilder();
 		styleBuilder.width(50, Unit.PX);
@@ -302,9 +362,13 @@ public class ReplaceBatchPanel extends FramedPanel implements
 					sb.appendHtmlConstant("<span " + style + ">"
 							+ DON_T_REPLACE + "</span>");
 				} else {
+
 					String style = "style='color: green;font-weight:normal'";
-					sb.appendHtmlConstant("<span " + style + ">" + value
-							+ "</span>");
+					sb.appendHtmlConstant("<span "
+							+ style
+							+ ">"
+							+ new SafeHtmlBuilder().appendEscaped(value)
+									.toSafeHtml().asString() + "</span>");
 				}
 
 			}
@@ -381,7 +445,7 @@ public class ReplaceBatchPanel extends FramedPanel implements
 		grid.setLoader(loader);
 		grid.setSelectionModel(sm);
 		number.initPlugin(grid);
-		grid.setHeight("376px");
+		grid.setHeight(GRID_HEIGHT);
 		grid.getView().setStripeRows(true);
 		grid.getView().setColumnLines(true);
 		grid.getView().setAutoFill(true);
@@ -395,13 +459,13 @@ public class ReplaceBatchPanel extends FramedPanel implements
 
 		ToolBar toolBar = new ToolBar();
 		toolBar.add(info);
-		toolBar.addStyleName(ThemeStyles.getStyle().borderTop());
+		toolBar.addStyleName(ThemeStyles.get().style().borderTop());
 		toolBar.getElement().getStyle().setProperty("borderBottom", "none");
 
 		btnSave = new TextButton("Save");
 		btnSave.setIcon(ResourceBundle.INSTANCE.save());
 		btnSave.setIconAlign(IconAlign.RIGHT);
-		btnSave.setTitle("Save");
+		btnSave.setToolTip("Save");
 		btnSave.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -415,7 +479,7 @@ public class ReplaceBatchPanel extends FramedPanel implements
 		btnClose = new TextButton("Close");
 		btnClose.setIcon(ResourceBundle.INSTANCE.close());
 		btnClose.setIconAlign(IconAlign.RIGHT);
-		btnClose.setTitle("Close");
+		btnClose.setToolTip("Close");
 		btnClose.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -428,134 +492,219 @@ public class ReplaceBatchPanel extends FramedPanel implements
 		flowButton.setHBoxLayoutAlign(HBoxLayoutAlign.MIDDLE);
 		flowButton.setPack(BoxLayoutPack.CENTER);
 
-		flowButton.add(btnSave, new BoxLayoutData(new Margins(2, 4, 2, 4)));
-		flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
+		BoxLayoutData boxLayoutData = new BoxLayoutData(new Margins(2, 4, 2, 4));
+		flowButton.add(btnSave, boxLayoutData);
+		flowButton.add(btnClose, boxLayoutData);
 
 		VerticalLayoutContainer v = new VerticalLayoutContainer();
 		v.add(toolBarHead, new VerticalLayoutData(1, -1, new Margins(0)));
-		v.add(grid, new VerticalLayoutData(-1, -1, new Margins(0)));
+		v.add(grid, new VerticalLayoutData(1, -1, new Margins(0)));
 		v.add(toolBar, new VerticalLayoutData(1, 25, new Margins(0)));
-		v.add(flowButton, new VerticalLayoutData(-1, 36,
-				new Margins(5, 2, 5, 2)));
+		v.add(flowButton,
+				new VerticalLayoutData(1, 36, new Margins(5, 2, 5, 2)));
 		add(v);
 
-		if (curation) {
+		setSelectedColumn();
+
+	}
+
+	protected void update(ColumnData column) {
+		this.column = column;
+		if (column == null) {
+			setSelectedColumn();
+		} else {
+			columnLocalId = column.getColumnId();
+			connection=null;
+			conditionCode=null;
+			refColumn = null;
+			validationColumnColumnId = null;
+			hasValidationColumns = false;
+			clear();
+			retrieveValidationColumn();
+		} 
+		
+
+	}
+
+	protected void setSelectedColumn() {
+		if (column == null) {
+			columnLocalId=null;
+			connection = null;
+			conditionCode=null;
+			refColumn = null;
+			validationColumnColumnId = null;
+			hasValidationColumns = false;
+			comboCols.reset();
 			storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
 					.getShowOccurrencesType());
-			if (connection != null) {
-				Log.debug("Selected connection: " + connection);
-				connectionField.setValue(connection.getLabel());
-				connectionField.setVisible(true);
-				btnDisconnect.setVisible(true);
-				btnConnect.setVisible(false);
-				btnConnect.enable();
-
-			} else {
-
+			Log.debug("Not Is View Column");
+			connectionField.setVisible(false);
+			btnDisconnect.setVisible(false);
+			btnConnect.setVisible(false);
+			if(curation){
+				comboCols.setReadOnly(true);
 			}
 			toolBarHead.forceLayout();
 		} else {
-			if (column.isViewColumn()) {
-				Log.debug("Is View Column");
-				storeShowOccurrencesType
-						.add(ShowOccurrencesTypeStore.onlyErrorsElement);
-				ColumnViewData cViewData = column.getColumnViewData();
-				RefColumn refCol = new RefColumn(String.valueOf(cViewData
-						.getTargetTableId()),
-						cViewData.getTargetTableColumnId());
-				retrieveConnectionForViewColumn(refCol);
-			} else {
+			comboCols.setValue(column);
+			if (curation) {
+				comboCols.setReadOnly(true);
 				storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
 						.getShowOccurrencesType());
-				Log.debug("Not Is View Column");
-				connectionField.setVisible(false);
-				btnDisconnect.setVisible(false);
-				toolBarHead.forceLayout();
+				if (connection != null) {
+					Log.debug("Selected connection: " + connection);
+					connectionField.setValue(connection.getLabel());
+					connectionField.setVisible(true);
+					btnDisconnect.setVisible(true);
+					btnConnect.setVisible(false);
+					btnConnect.disable();
+					toolBarHead.forceLayout();
+				} else {
+					if (column.isViewColumn()) {
+						Log.debug("Is View Column");
+						// storeShowOccurrencesType
+						// .add(ShowOccurrencesTypeStore.onlyErrorsElement);
+						storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
+								.getShowOccurrencesType());
+
+						ColumnViewData cViewData = column.getColumnViewData();
+						RefColumn refCol = new RefColumn(String.valueOf(cViewData
+								.getTargetTableId()),
+								cViewData.getTargetTableColumnId());
+						retrieveConnectionForViewColumn(refCol);
+					} else {
+						storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
+								.getShowOccurrencesType());
+						Log.debug("Not Is View Column");
+						connectionField.setVisible(false);
+						btnDisconnect.setVisible(false);
+						btnConnect.setVisible(true);
+						btnConnect.setEnabled(true);
+						toolBarHead.forceLayout();
+					}
+				}
+				
+			} else {
+
+				if (column.isViewColumn()) {
+					Log.debug("Is View Column");
+					// storeShowOccurrencesType
+					// .add(ShowOccurrencesTypeStore.onlyErrorsElement);
+					storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
+							.getShowOccurrencesType());
+
+					ColumnViewData cViewData = column.getColumnViewData();
+					RefColumn refCol = new RefColumn(String.valueOf(cViewData
+							.getTargetTableId()),
+							cViewData.getTargetTableColumnId());
+					retrieveConnectionForViewColumn(refCol);
+				} else {
+					storeShowOccurrencesType.addAll(ShowOccurrencesTypeStore
+							.getShowOccurrencesType());
+					Log.debug("Not Is View Column");
+					connectionField.setVisible(false);
+					btnDisconnect.setVisible(false);
+					btnConnect.setVisible(true);
+					btnConnect.setEnabled(true);
+					toolBarHead.forceLayout();
+				}
+
+			}
+		}
+	}
+
+	protected SelectionHandler<ColumnData> comboColsSelection() {
+		SelectionHandler<ColumnData> selectionHandler = new SelectionHandler<ColumnData>() {
+
+			@Override
+			public void onSelection(SelectionEvent<ColumnData> event) {
+				if (event.getSelectedItem() != null) {
+					ColumnData col = event.getSelectedItem();
+					Log.debug("Col selected:" + col.toString());
+					column = col;
+					btnSave.enable();
+					update(col);
+				} else {
+					column = null;
+					btnSave.disable();
+					update(null);
+				}
+			}
+		};
+
+		return selectionHandler;
+	}
+
+	private void cleanCells(Element elem) {
+		NodeList<Element> tds = elem.<XElement> cast().select("td");
+		for (int i = 0; i < tds.getLength(); i++) {
+			Element td = tds.getItem(i);
+
+			if (!td.hasChildNodes() && td.getClassName().equals("")) {
+				td.removeFromParent();
+			}
+		}
+	}
+
+	protected void retrieveColumnsWithOnlyViewColumnInRel() {
+		Log.debug("Retrieve Column by ColumnId: columnLocalId:" + columnLocalId
+				+ ", trId:" + trId);
+		TDGWTServiceAsync.INSTANCE.getColumnWithOnlyViewColumnInRel(trId,
+				new AsyncCallback<ArrayList<ColumnData>>() {
+
+					public void onFailure(Throwable caught) {
+						if (caught instanceof TDGWTSessionExpiredException) {
+							eventBus.fireEvent(new SessionExpiredEvent(
+									SessionExpiredType.EXPIREDONSERVER));
+						} else {
+							if (caught instanceof TDGWTIsLockedException) {
+								Log.error(caught.getLocalizedMessage());
+								UtilsGXT3.alert("Error Locked",
+										caught.getLocalizedMessage());
+							} else {
+								if (caught instanceof TDGWTIsFinalException) {
+									Log.error(caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error Final",
+											caught.getLocalizedMessage());
+								} else {
+									Log.error("load column failure:"
+											+ caught.getLocalizedMessage());
+									UtilsGXT3.alert("Error retrieving column",
+											"Error retrieving column");
+								}
+							}
+						}
+					}
+
+					public void onSuccess(ArrayList<ColumnData> result) {
+						Log.debug("Column: " + result);
+						columns = result;
+						retrieveColumn();
+						if (column == null) {
+							hasValidationColumns = false;
+							create();
+						} else {
+							retrieveValidationColumn();
+						}
+					}
+
+				});
+	}
+
+	protected void retrieveColumn() {
+		for (ColumnData c : columns) {
+			if (columnLocalId != null
+					&& c.getColumnId().compareTo(columnLocalId) == 0) {
+				column = c;
+				return;
 			}
 
 		}
 
 	}
 
-	protected void retrieveColumn() {
-		TDGWTServiceAsync.INSTANCE.getColumn(trId, columnName,
-				new AsyncCallback<ColumnData>() {
-
-					public void onFailure(Throwable caught) {
-						if (caught instanceof TDGWTSessionExpiredException) {
-							eventBus.fireEvent(new SessionExpiredEvent(
-									SessionExpiredType.EXPIREDONSERVER));
-						} else {
-							if (caught instanceof TDGWTIsLockedException) {
-								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
-										caught.getLocalizedMessage());
-							} else {
-								if (caught instanceof TDGWTIsFinalException) {
-									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
-											caught.getLocalizedMessage());
-								} else {
-									Log.error("load column failure:"
-											+ caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error retrieving column",
-											"Error retrieving column");
-								}
-							}
-						}
-					}
-
-					public void onSuccess(ColumnData result) {
-						Log.debug("Column: " + result);
-						column = result;
-						retriveValidationColumn();
-					}
-
-				});
-	}
-
-	protected void retrieveColumnByColumnId() {
-		Log.debug("Retrieve Column by ColumnId: columnId:" + columnId
-				+ ", trId:" + trId);
-		TDGWTServiceAsync.INSTANCE.getColumn(columnId, trId,
-				new AsyncCallback<ColumnData>() {
-
-					public void onFailure(Throwable caught) {
-						if (caught instanceof TDGWTSessionExpiredException) {
-							eventBus.fireEvent(new SessionExpiredEvent(
-									SessionExpiredType.EXPIREDONSERVER));
-						} else {
-							if (caught instanceof TDGWTIsLockedException) {
-								Log.error(caught.getLocalizedMessage());
-								UtilsGXT3.alert("Error Locked",
-										caught.getLocalizedMessage());
-							} else {
-								if (caught instanceof TDGWTIsFinalException) {
-									Log.error(caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error Final",
-											caught.getLocalizedMessage());
-								} else {
-									Log.error("load column failure:"
-											+ caught.getLocalizedMessage());
-									UtilsGXT3.alert("Error retrieving column",
-											"Error retrieving column");
-								}
-							}
-						}
-					}
-
-					public void onSuccess(ColumnData result) {
-						Log.debug("Column: " + result);
-						column = result;
-						columnName = result.getName();
-						retriveValidationColumn();
-					}
-
-				});
-	}
-
-	protected void retriveValidationColumn() {
-		TDGWTServiceAsync.INSTANCE.getValidationColumns(trId, columnName,
+	protected void retrieveValidationColumn() {
+		TDGWTServiceAsync.INSTANCE.getValidationColumns(columnLocalId, trId,
 				new AsyncCallback<ArrayList<ColumnData>>() {
 
 					public void onFailure(Throwable caught) {
@@ -640,7 +789,15 @@ public class ReplaceBatchPanel extends FramedPanel implements
 	 */
 	protected void loadData(ListLoadConfig loadConfig,
 			final AsyncCallback<ListLoadResult<ReplaceEntry>> callback) {
-
+		
+		if(column==null){
+			ListLoadResultBean<ReplaceEntry> loadedResult = new ListLoadResultBean<ReplaceEntry>(
+					getRecord(new ArrayList<Occurrences>()));
+			Log.debug("created " + loadedResult.toString());
+			callback.onSuccess(loadedResult);
+			return;
+		}
+		
 		OccurrencesForReplaceBatchColumnSession occurrencesSession = new OccurrencesForReplaceBatchColumnSession(
 				column, showOccurencesType, hasValidationColumns,
 				conditionCode, validationColumnColumnId);
@@ -1088,7 +1245,7 @@ public class ReplaceBatchPanel extends FramedPanel implements
 					public void onSuccess(ColumnData result) {
 						Log.debug("Column: " + result);
 						connection = result;
-						retrieveColumnByColumnId();
+						retrieveColumnsWithOnlyViewColumnInRel();
 					}
 
 				});
