@@ -124,7 +124,7 @@ public class ConnectCodelistDialog extends Window implements
 		btnApply = new TextButton("Connect");
 		btnApply.setIcon(ResourceBundle.INSTANCE.codelistLink());
 		btnApply.setIconAlign(IconAlign.RIGHT);
-		btnApply.setTitle("Connect");
+		btnApply.setToolTip("Connect");
 		btnApply.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -138,7 +138,7 @@ public class ConnectCodelistDialog extends Window implements
 		btnClose = new TextButton("Close");
 		btnClose.setIcon(ResourceBundle.INSTANCE.close());
 		btnClose.setIconAlign(IconAlign.RIGHT);
-		btnClose.setTitle("Close");
+		btnClose.setToolTip("Close");
 		btnClose.addSelectHandler(new SelectHandler() {
 
 			public void onSelect(SelectEvent event) {
@@ -152,13 +152,14 @@ public class ConnectCodelistDialog extends Window implements
 		flowButton.setHBoxLayoutAlign(HBoxLayoutAlign.MIDDLE);
 		flowButton.setPack(BoxLayoutPack.CENTER);
 
-		flowButton.add(btnApply, new BoxLayoutData(new Margins(2, 4, 2, 4)));
-		flowButton.add(btnClose, new BoxLayoutData(new Margins(2, 4, 2, 4)));
+		BoxLayoutData boxLayoutData=new BoxLayoutData(new Margins(2, 4, 2, 4));
+		flowButton.add(btnApply, boxLayoutData);
+		flowButton.add(btnClose, boxLayoutData);
 
 		VerticalLayoutContainer v = new VerticalLayoutContainer();
 		v.add(comboDimensionTypeLabel, new VerticalLayoutData(1, -1));
 		v.add(comboColumnReferenceTypeLabel, new VerticalLayoutData(1, -1));
-		v.add(flowButton, new VerticalLayoutData(-1, 36,
+		v.add(flowButton, new VerticalLayoutData(1, 36,
 				new Margins(5, 2, 5, 2)));
 
 		panel.add(v);
@@ -290,9 +291,11 @@ public class ConnectCodelistDialog extends Window implements
 						storeComboColumnReferenceType.clear();
 						storeComboColumnReferenceType.addAll(result);
 						storeComboColumnReferenceType.commitChanges();
+						
 						comboColumnReferenceTypeLabel.setVisible(true);
 						comboColumnReferenceType.setMinListWidth(191);
-
+						comboColumnReferenceTypeLabel.forceLayout();
+						
 					}
 				});
 
